module.exports = function( grunt ) {
	var fitness = {
		banner: '/*!\n' +
		 '* Fitness\n' +
		 '*\n' +
		 '* (c) Copyright mythemeshop.com\n' +
		 '*\n' +
		 '* @version 1.0.0\n' +
		 '* @author  MyThemeShop\n' +
		 '*/\n',
		 uglify: {
			 options: {
				'includes/admin/libs/mts-options/js/fitness-options.js': [

					// Base
					'includes/admin/libs/mts-options/src/options.js',

					// Fields
					'includes/admin/libs/mts-options/fields/ace_editor/field_ace_editor.js',
					'includes/admin/libs/mts-options/fields/background/field_background.js',
					'includes/admin/libs/mts-options/fields/color/field_color.js',
					'includes/admin/libs/mts-options/fields/date/field_date.js',
					'includes/admin/libs/mts-options/fields/group/field_group.js',
					'includes/admin/libs/mts-options/fields/icon_select/field_icon_select.js',
					'includes/admin/libs/mts-options/fields/layout/field_layout.js',
					'includes/admin/libs/mts-options/fields/layout2/field_layout2.js',
					'includes/admin/libs/mts-options/fields/multi_text/field_multi_text.js',
					'includes/admin/libs/mts-options/fields/radio_img/field_radio_img.js',
					'includes/admin/libs/mts-options/fields/typography/field_typography.js',
					'includes/admin/libs/mts-options/fields/typography_collections/field_typography_collections.js',
					'includes/admin/libs/mts-options/fields/upload/field_upload.js'
				]
			 }
		 }
	};

	// Project configuration.
	grunt.initConfig({
		pkg: grunt.file.readJSON( 'package.json' ),
		uglify: {
			moptions: {
				options: {
					banner: fitness.banner,
					preserveComments: 'some',
					beautify: false,
					compress: true,
					quoteStyle: 3,
					mangle: false
				},
				files: fitness.uglify.options
			}
		},

		// Generate POT files.
		makepot: {
			dist: {
				options: {
					type: 'wp-theme',
					mainFile: 'style.css',
					domainPath: 'languages',
					potHeaders: {
						'report-msgid-bugs-to': 'https://community.mythemeshop.com/',
						'language-team': 'MyThemeShop <support-team@mythemeshop.com>'
					},
					potFilename: 'fitness.pot',
					exclude: [
						'node_modules/.*'
					]
				}
			}
		},

		// Check textdomain errors.
		checktextdomain: {
			options: {
				keywords: [
					'__:1,2d',
					'_e:1,2d',
					'_x:1,2c,3d',
					'_ex:1,2c,3d',
					'_n:1,2,4d',
					'_nx:1,2,4c,5d',
					'_n_noop:1,2,3d',
					'_nx_noop:1,2,3c,4d',
					'esc_attr__:1,2d',
					'esc_attr_e:1,2d',
					'esc_attr_x:1,2c,3d',
					'esc_html__:1,2d',
					'esc_html_e:1,2d',
					'esc_html_x:1,2c,3d'
				]
			},

			plugin: {
				src: ['**/*.php', '!node_modules/**'],
				expand: true,
				options: {
					text_domain: [ 'fitness', 'woocommerce' ]
				}
			}
		}
	});

	// Default task(s).
	grunt.registerTask( 'default', [
		'uglify'
	]);

	grunt.registerTask( 'pot', [
		'checktextdomain', 'makepot'
	]);

	// Load the plugin that provides the tasks.
	grunt.loadNpmTasks( 'grunt-contrib-uglify' );
	grunt.loadNpmTasks( 'grunt-wp-i18n' );

	// Quality Assurance
	grunt.loadNpmTasks( 'grunt-checktextdomain' );
};
